This directory contains the documentation.


Run `pip install -r requirements.txt` in this directory to install the dependencies to build the documentation.

Run `make html` in this directory to build the docs on your system. See `build/html` for the result.


Automatic deployment of documentation is planned.
